@@ -27,6 +27,7 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <glib-object.h>
+#include <libebook/e-contact.h>
 #include <gnokii.h>
 
 #include <bluetooth/bluetooth.h>
@@ -53,29 +54,34 @@ phonemgr_utils_gn_statemachine_clear (struct gn_statemachine *state)
 const char *
 phonemgr_utils_gn_error_to_string (gn_error error, PhoneMgrError *perr)
 {
-	g_return_val_if_fail (perr != NULL, NULL);
-	*perr = -1;
+	if (perr != NULL)
+		*perr = -1;
 
 	switch (error) {
 	/* General codes */
 	case GN_ERR_NONE:
 		return NULL;
 	case GN_ERR_FAILED:
-		*perr = PHONEMGR_ERROR_COMMAND_FAILED;
+		if (perr != NULL)
+			*perr = PHONEMGR_ERROR_COMMAND_FAILED;
 		return "Command failed";
 	case GN_ERR_UNKNOWNMODEL:
-		*perr = PHONEMGR_ERROR_UNKNOWN_MODEL;
+		if (perr != NULL)
+			*perr = PHONEMGR_ERROR_UNKNOWN_MODEL;
 		return "Model specified isn't known/supported.";
 	case GN_ERR_INVALIDSECURITYCODE:
 		return "Invalid Security code.";
 	case GN_ERR_INTERNALERROR:
-		*perr = PHONEMGR_ERROR_INTERNAL_ERROR;
+		if (perr != NULL)
+			*perr = PHONEMGR_ERROR_INTERNAL_ERROR;
 		return "Problem occured internal to model specific code.";
 	case GN_ERR_NOTIMPLEMENTED:
-		*perr = PHONEMGR_ERROR_NOT_IMPLEMENTED;
+		if (perr != NULL)
+			*perr = PHONEMGR_ERROR_NOT_IMPLEMENTED;
 		return "Command called isn't implemented in model.";
 	case GN_ERR_NOTSUPPORTED:
-		*perr = PHONEMGR_ERROR_NOT_SUPPORTED;
+		if (perr != NULL)
+			*perr = PHONEMGR_ERROR_NOT_SUPPORTED;
 		return "Function not supported by the phone";
 	case GN_ERR_USERCANCELED:
 		return "User aborted the action.";
@@ -85,17 +91,20 @@ phonemgr_utils_gn_error_to_string (gn_error error, PhoneMgrError *perr)
 		return "The specified memory is full.";
 	/* Statemachine */
 	case GN_ERR_NOLINK:
-		*perr = PHONEMGR_ERROR_NO_LINK;
+		if (perr != NULL)
+			*perr = PHONEMGR_ERROR_NO_LINK;
 		return "Couldn't establish link with phone.";
 	case GN_ERR_TIMEOUT:
-		*perr = PHONEMGR_ERROR_TIME_OUT;
+		if (perr != NULL)
+			*perr = PHONEMGR_ERROR_TIME_OUT;
 		return "Command timed out.";
 	case GN_ERR_TRYAGAIN:
 		return "Try again.";
 	case GN_ERR_WAITING:
 		return "Waiting for the next part of the message.";
 	case GN_ERR_NOTREADY:
-		*perr = PHONEMGR_ERROR_NOT_READY;
+		if (perr != NULL)
+			*perr = PHONEMGR_ERROR_NOT_READY;
 		return "Device not ready.";
 	case GN_ERR_BUSY:
 		return "Command is still being executed.";
@@ -175,7 +184,7 @@ find_service_channel (bdaddr_t *adapter, bdaddr_t *device, gboolean only_gnapple
 {
 	sdp_session_t *sdp = NULL;
 	sdp_list_t *search = NULL, *attrs = NULL, *recs = NULL, *tmp;
-	uuid_t browse_uuid, service_id, obex_uuid;
+	uuid_t service_id;
 	uint32_t range = 0x0000ffff;
 	int channel = -1;
 
@@ -395,7 +404,7 @@ phonemgr_utils_driver_parse_start_tag (GMarkupParseContext *ctx,
 }
 
 static void
-totem_driver_model_free (void)
+phonemgr_driver_model_free (void)
 {
 	g_hash_table_destroy (driver_model);
 	driver_model = NULL;
@@ -411,7 +420,7 @@ phonemgr_utils_start_parse (void)
 	driver_model = g_hash_table_new_full
 		(g_str_hash, g_str_equal, g_free, g_free);
 
-	g_atexit (totem_driver_model_free);
+	g_atexit (phonemgr_driver_model_free);
 
 	if (g_file_get_contents (DATA_DIR"/phones.xml",
 				&buf, &buf_len, &err))
@@ -456,7 +465,6 @@ phonemgr_utils_guess_driver (PhonemgrState *phone_state, const char *device,
 {
 	const char *model;
 	char *driver;
-	gn_error err;
 
 	driver = phonemgr_utils_driver_for_device (device);
 	if (driver != NULL)
@@ -466,9 +474,7 @@ phonemgr_utils_guess_driver (PhonemgrState *phone_state, const char *device,
 		return NULL;
 
 	model = gn_lib_get_phone_model (&phone_state->state);
-
 	if (model == NULL) {
-		PhoneMgrError perr;
 		g_warning ("gn_lib_get_phone_model failed");
 		goto bail;
 	}
@@ -516,17 +522,24 @@ phonemgr_utils_connect (const char *device, const char *driver, int channel, gbo
 		g_free (config);
 	}
 
-	if (gn_cfg_memory_read ((const char **)lines) < 0) {
-		g_warning ("gn_cfg_memory_read");
+	err = gn_cfg_memory_read ((const char **)lines);
+	if (err != GN_ERR_NONE) {
+		PhoneMgrError perr;
+		g_warning ("gn_cfg_memory_read: %s",
+			   phonemgr_utils_gn_error_to_string (err, &perr));
 		g_strfreev (lines);
 		return NULL;
 	}
 	g_strfreev (lines);
 
+	memset (&data, 0, sizeof (data));
 	phonemgr_utils_gn_statemachine_clear (&state);
 
-	if (gn_cfg_phone_load("", &state) < 0) {
-		g_warning ("gn_cfg_phone_load");
+	err = gn_cfg_phone_load ("", &state);
+	if (err != GN_ERR_NONE) {
+		PhoneMgrError perr;
+		g_warning ("gn_cfg_phone_load: %s",
+			   phonemgr_utils_gn_error_to_string (err, &perr));
 		return NULL;
 	}
 
@@ -538,7 +551,7 @@ phonemgr_utils_connect (const char *device, const char *driver, int channel, gbo
 		return NULL;
 	}
 
-	phone_state = g_new (PhonemgrState, 1);
+	phone_state = g_new0 (PhonemgrState, 1);
 	phone_state->data = data;
 	phone_state->state = state;
 
@@ -576,7 +589,7 @@ phonemgr_utils_tell_driver (const char *addr)
 	channel = -1;
 	type = phonemgr_utils_address_is (addr);
 	if (phonemgr_utils_connection_is_supported (type) == FALSE) {
-		g_warning ("Connection type isn't support by your gnokii build");
+		g_warning ("Connection type isn't supported by your libgnokii build");
 		return;
 	}
 
@@ -623,7 +636,7 @@ phonemgr_utils_write_gnokii_config (const char *addr)
 	channel = -1;
 	type = phonemgr_utils_address_is (addr);
 	if (phonemgr_utils_connection_is_supported (type) == FALSE) {
-		g_warning ("Connection type isn't support by your gnokii build");
+		g_warning ("Connection type isn't supported by your libgnokii build");
 		return;
 	}
 
@@ -719,3 +732,60 @@ phonemgr_utils_connection_is_supported (PhonemgrConnectionType type)
 	return gn_lib_is_connectiontype_supported (conntype);
 }
 
+#define SET_ENTRY(field, string) {				\
+	const char *s;						\
+	s = e_contact_get_const (contact, field);		\
+	if (s)							\
+		strncpy (string, s, sizeof (string));	\
+}
+
+#define SET_SUB_ENTRY(field, type) {						\
+	if (entry->subentries_count < GN_PHONEBOOK_SUBENTRIES_MAX_NUMBER) {	\
+		entry->subentries[entry->subentries_count].entry_type = type;	\
+		SET_ENTRY (field, entry->subentries[entry->subentries_count++].data.number); \
+	}									\
+}
+
+gboolean
+vcard_to_phonebook_entry (const char *vcard, gn_phonebook_entry *entry)
+{
+	EContact *contact;
+
+	contact = e_contact_new_from_vcard (vcard);
+	SET_ENTRY(E_CONTACT_FULL_NAME, entry->name);
+	if (entry->name == NULL)
+		return FALSE;
+
+	SET_ENTRY (E_CONTACT_PHONE_PRIMARY, entry->number);
+	if (entry->number == NULL)
+		SET_ENTRY(E_CONTACT_PHONE_HOME, entry->number);
+	if (entry->number == NULL)
+		SET_ENTRY(E_CONTACT_PHONE_MOBILE, entry->number);
+	if (entry->number == NULL)
+		return FALSE;
+
+	SET_ENTRY(E_CONTACT_FAMILY_NAME, entry->person.family_name);
+	SET_ENTRY(E_CONTACT_GIVEN_NAME, entry->person.given_name);
+	SET_ENTRY(E_CONTACT_TITLE, entry->person.honorific_prefixes);
+	SET_SUB_ENTRY (E_CONTACT_HOMEPAGE_URL, GN_PHONEBOOK_ENTRY_URL);
+	if (entry->subentries_count == 0)
+		SET_SUB_ENTRY (E_CONTACT_BLOG_URL, GN_PHONEBOOK_ENTRY_URL);
+	SET_SUB_ENTRY (E_CONTACT_EMAIL_1, GN_PHONEBOOK_ENTRY_Email);
+	SET_SUB_ENTRY (E_CONTACT_EMAIL_2, GN_PHONEBOOK_ENTRY_Email);
+	SET_SUB_ENTRY (E_CONTACT_EMAIL_3, GN_PHONEBOOK_ENTRY_Email);
+	SET_SUB_ENTRY (E_CONTACT_EMAIL_4, GN_PHONEBOOK_ENTRY_Email);
+	SET_SUB_ENTRY (E_CONTACT_ADDRESS_LABEL_HOME, GN_PHONEBOOK_ENTRY_Postal);
+	SET_SUB_ENTRY (E_CONTACT_ADDRESS_LABEL_WORK, GN_PHONEBOOK_ENTRY_Postal);
+	SET_SUB_ENTRY (E_CONTACT_ADDRESS_LABEL_OTHER, GN_PHONEBOOK_ENTRY_Postal);
+	SET_SUB_ENTRY (E_CONTACT_NOTE, GN_PHONEBOOK_ENTRY_Note);
+	SET_SUB_ENTRY (E_CONTACT_PHONE_BUSINESS, GN_PHONEBOOK_NUMBER_Work);
+	SET_SUB_ENTRY (E_CONTACT_PHONE_BUSINESS_2, GN_PHONEBOOK_NUMBER_Work);
+	SET_SUB_ENTRY (E_CONTACT_PHONE_HOME, GN_PHONEBOOK_NUMBER_Home);
+	SET_SUB_ENTRY (E_CONTACT_PHONE_HOME_2, GN_PHONEBOOK_NUMBER_Home);
+	SET_SUB_ENTRY (E_CONTACT_PHONE_MOBILE, GN_PHONEBOOK_NUMBER_Mobile);
+	SET_SUB_ENTRY (E_CONTACT_PHONE_BUSINESS_FAX, GN_PHONEBOOK_NUMBER_Fax);
+	SET_SUB_ENTRY (E_CONTACT_PHONE_HOME_FAX, GN_PHONEBOOK_NUMBER_Fax);
+
+	return TRUE;
+}
+
