@@ -23,10 +23,7 @@
 #define _APP_H
 
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <gconf/gconf-client.h>
-#include <gst/gst.h>
-#include <gnomebt-controller.h>
 
 #include "phonemgr-listener.h"
 #include "phonemgr-object.h"
@@ -35,7 +32,7 @@ typedef struct _appinfo {
 	/* gui stuff */
 	GtkStatusIcon *tray_icon;
 	GtkMenu *menu;
-	GladeXML    *ui;
+	GtkBuilder    *ui;
 	int    iconstate;
 	int    chars;
 	GtkWidget *send_item;
@@ -45,7 +42,6 @@ typedef struct _appinfo {
 	GConfClient *client;
 	PhonemgrListener    *listener;
 	PhonemgrObject      *object;
-	GstElement *playbin;
 
 	/* connection state */
 	char   *devname;
@@ -88,6 +84,7 @@ void create_send_dialog (MyApp *app, GtkDialog *parent, const char *recip);
 void enable_flasher (MyApp *app);
 void play_alert (MyApp *app);
 void ui_hide (MyApp *app);
+GtkWidget *bluetooth_chooser_button_create (void);
 
 /* connection functions */
 void free_connection (MyApp *app);
@@ -100,23 +97,6 @@ void set_icon_state (MyApp *app);
 void tray_icon_init (MyApp *app);
 void tray_icon_hide (MyApp *app);
 
-enum {
-    ICON_IDLE,
-    ICON_CONNECTING,
-    ICON_MESSAGE,
-    ICON_ERROR
-};
-
-#define CONFBASE "/apps/gnome-phone-manager"
-
-enum {
-	CONNECTION_BLUETOOTH,
-	CONNECTION_SERIAL1,
-	CONNECTION_SERIAL2,
-	CONNECTION_IRCOMM,
-	CONNECTION_OTHER,
-	CONNECTION_LAST
-};
-
+#include "phonemgr-conf.h"
 
 #endif
