@@ -32,11 +32,9 @@
 #include <gtk/gtk.h>
 #include <string.h>
 #include <libedataserver/e-source-list.h>
+#include <libedataserverui/e-client-utils.h>
 #include "e-phone-entry.h"
 
-#define GCONF_COMPLETION "/apps/evolution/addressbook"
-#define GCONF_COMPLETION_SOURCES GCONF_COMPLETION "/sources"
-
 #define CONTACT_FORMAT "%s (%s)"
 
 /* Signals */
@@ -91,8 +89,7 @@ text_changed (GtkEditable *entry, gpointer user_data)
 		return;
 	}
 
-	if (pentry->text != NULL)
-		g_free (pentry->text);
+	g_free (pentry->text);
 	pentry->text = current;
 
 	if (pentry->phone_number != NULL) {
@@ -188,31 +185,13 @@ add_sources (EContactEntry *entry)
 {
 	ESourceList *source_list;
 
-	source_list =
-		e_source_list_new_for_gconf_default (GCONF_COMPLETION_SOURCES);
-	e_contact_entry_set_source_list (E_CONTACT_ENTRY (entry),
-			source_list);
-	g_object_unref (source_list);
-}
-
-static void
-sources_changed_cb (GConfClient *client, guint cnxn_id,
-		GConfEntry *entry, EContactEntry *entry_widget)
-{
-	add_sources (entry_widget);
-}
-
-static void
-setup_source_changes (EPhoneEntry *entry)
-{
-	GConfClient *gc;
-
-	gc = gconf_client_get_default ();
-	gconf_client_add_dir (gc, GCONF_COMPLETION,
-			GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
-	gconf_client_notify_add (gc, GCONF_COMPLETION,
-			(GConfClientNotifyFunc) sources_changed_cb,
-			entry, NULL, NULL);
+	if (e_client_utils_get_sources (&source_list,
+					E_CLIENT_SOURCE_TYPE_CONTACTS,
+					NULL)) {
+		e_contact_entry_set_source_list (E_CONTACT_ENTRY (entry),
+						 source_list);
+		g_object_unref (source_list);
+	}
 }
 
 static void
@@ -221,7 +200,6 @@ e_phone_entry_init (EPhoneEntry *entry)
 	EContactField fields[] = { E_CONTACT_FULL_NAME, E_CONTACT_NICKNAME, E_CONTACT_ORG, E_CONTACT_PHONE_MOBILE, 0 };
 
 	add_sources (E_CONTACT_ENTRY (entry));
-	setup_source_changes (E_PHONE_ENTRY (entry));
 	e_contact_entry_set_search_fields (E_CONTACT_ENTRY (entry), (const EContactField *)fields);
 	e_contact_entry_set_display_func (E_CONTACT_ENTRY (entry), test_display_func, NULL, NULL);
 	g_signal_connect (G_OBJECT (entry), "contact_selected",
@@ -234,10 +212,8 @@ static void
 e_phone_entry_class_init (EPhoneEntryClass *klass)
 {
   GObjectClass *object_class;
-  GtkWidgetClass *widget_class;
   
   object_class = (GObjectClass *) klass;
-  widget_class = (GtkWidgetClass *) klass;
   
   /* GObject */
   object_class->finalize = e_phone_entry_finalize;
