@@ -37,21 +37,18 @@ about_activated(GtkMenuItem *item, gpointer data)
 {
 	const char *authors[] = { "Bastien Nocera <hadess@hadess.net>", "Edd Dumbill <edd@usefulinc.com>", NULL };
 	const char *documenters[] = { NULL };
-	const char *translator_credits = _("translator_credits");
 
 	gtk_show_about_dialog (NULL,
 			       "authors", authors,
 			       "comments", _("Send and receive messages from your mobile phone."),
-			       "copyright", "Copyright \xc2\xa9 2003-2004 Edd Dumbill\nCopyright \xc2\xa9 2005-2007 Bastien Nocera",
+			       "copyright", "Copyright \xc2\xa9 2003-2004 Edd Dumbill\n" \
+			                    "Copyright \xc2\xa9 2005-2010 Bastien Nocera\n" \
+			                    "Copyright \xc2\xa9 2011 Daniele Forsi",
 			       "documenters", documenters,
 			       "logo-icon-name", "phone",
-#if GTK_CHECK_VERSION (2, 11, 0)
 			       "program-name", _("Phone Manager"),
-#else
-			       "name", _("Phone Manager"),
-#endif /* GTK+ 2.11.0 */
 			       "version", VERSION,
-			       "translator-credits", strcmp (translator_credits, "translator_credits") != 0 ?  translator_credits : NULL,
+			       "translator-credits", _("translator_credits"),
 			       "website", "http://live.gnome.org/PhoneManager",
 			       "website-label", _("Phone Manager website"),
 			       NULL);
@@ -110,6 +107,11 @@ construct_menu (MyApp *app)
 	gtk_widget_show (item);
 	gtk_menu_shell_append (GTK_MENU_SHELL(app->menu), item);
 
+	item = gtk_separator_menu_item_new ();
+
+	gtk_widget_show (item);
+	gtk_menu_shell_append (GTK_MENU_SHELL(app->menu), item);
+
 	item = gtk_image_menu_item_new_from_stock (GTK_STOCK_QUIT, NULL);
 	g_signal_connect (G_OBJECT(item), "activate",
 			  G_CALLBACK (quit_activated), (gpointer) app);
