@@ -22,9 +22,6 @@
 #include <string.h>
 #include "e-phone-entry.h"
 
-#define GCONF_COMPLETION "/apps/evolution/addressbook"
-#define GCONF_COMPLETION_SOURCES GCONF_COMPLETION "/sources"
-
 #define CONTACT_FORMAT "%s (%s)"
 
 static char *phone_number = NULL;
@@ -45,8 +42,6 @@ int main (int argc, char **argv)
 {
 	GtkWidget *window, *entry;
 
-	g_thread_init (NULL);
-
 	gtk_init (&argc, &argv);
 
 	window = gtk_dialog_new ();
