@@ -68,8 +68,8 @@ chooser_created (BluetoothChooserButton *button, BluetoothChooser *chooser, gpoi
 		     NULL);
 }
 
-static
-GtkBuilder *get_ui (MyApp *app, char *widget)
+static GtkBuilder *
+get_ui (MyApp *app, char *widget)
 {
 	char *fname;
 	GError* error = NULL;
@@ -120,22 +120,34 @@ play_alert (MyApp *app)
 }
 
 static void
-set_dependent_widget (MyApp *app, int conn_type, gboolean active)
+is_available_changed (BluetoothChooserButton *button, BluetoothChooser *chooser, gpointer data)
 {
-	GtkWidget *w = NULL;
+	gboolean is_sensitive;
+	GtkWidget *btdevice = GTK_WIDGET (data);
+
+	/* Make it sensitive only if the corresponding radio button is selected */
+	is_sensitive = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (btdevice)) &&
+	               phonemgr_utils_connection_is_supported (PHONEMGR_CONNECTION_BLUETOOTH) &&
+	               bluetooth_chooser_button_available (button);
+	gtk_widget_set_sensitive (GTK_WIDGET (button), is_sensitive);
+}
+
+static void
+widget_set_dependent_sensitive (GtkWidget *widget, int conn_type, gboolean active)
+{
+	GtkWidget *dependent;
+
+	dependent = GTK_WIDGET (g_object_get_data (G_OBJECT (widget), "dependent"));
+	if (dependent == NULL)
+		return;
+
 	switch (conn_type) {
 		case CONNECTION_BLUETOOTH:
-			/* only set sensitive if bluetooth available */
-			w = GTK_WIDGET (gtk_builder_get_object (app->ui, "btchooser"));
-			if (bluetooth_chooser_button_available (BLUETOOTH_CHOOSER_BUTTON (w)) == FALSE
-			    || phonemgr_utils_connection_is_supported (PHONEMGR_CONNECTION_BLUETOOTH) == FALSE)
-				active = FALSE;
-			gtk_widget_set_sensitive (w, active);
-			break;
-		case CONNECTION_OTHER:
-			w = GTK_WIDGET (gtk_builder_get_object (app->ui, "otherportentry"));
-			gtk_widget_set_sensitive (w, active);
-			break;
+			is_available_changed (BLUETOOTH_CHOOSER_BUTTON (dependent), NULL, widget);
+			return;
+		default:
+			gtk_widget_set_sensitive (dependent, active);
+			return;
 	}
 }
 
@@ -145,10 +157,10 @@ on_conn_port_change (GtkWidget *widget, MyApp *app)
 	gboolean active = gtk_toggle_button_get_active (
 				GTK_TOGGLE_BUTTON (widget));
 	int port;
-	
+
 	port = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "port"));
 
-	set_dependent_widget (app, port, active);
+	widget_set_dependent_sensitive (widget, port, active);
 	if (active) {
 		gconf_client_set_int (app->client,
 				      CONFBASE"/connection_type",
@@ -163,7 +175,7 @@ message_dialog_reply (GtkBuilder *ui)
 	GtkWidget *dialog = GTK_WIDGET (gtk_builder_get_object (ui, "sms_dialog"));
 	GtkLabel *sender = GTK_LABEL (
 			gtk_builder_get_object (ui, "senderlabel"));
-	
+
 	app = (MyApp *) g_object_get_data (G_OBJECT (dialog),
 			"app");
 
@@ -173,59 +185,57 @@ message_dialog_reply (GtkBuilder *ui)
 	return TRUE;
 }
 
-#define S_CONNECT(x, y) 	\
-	w = GTK_WIDGET (gtk_builder_get_object (app->ui, (x))); \
-	g_object_set_data (G_OBJECT (w), "port", GINT_TO_POINTER (y)); \
-	g_signal_connect (G_OBJECT (w), "toggled", \
-			G_CALLBACK (on_conn_port_change), (gpointer)app)
-					
-#define S_ACTIVE(x, y) \
-	w = GTK_WIDGET (gtk_builder_get_object (app->ui, (x))); \
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), ctype==y);
+static gulong
+s_connect (MyApp *app, const gchar *wname, const gchar *dependentname, gint port)
+{
+	GtkWidget *w, *dependent;
+
+	w = GTK_WIDGET (gtk_builder_get_object (app->ui, wname));
+	g_object_set_data (G_OBJECT (w), "port", GINT_TO_POINTER (port));
+	if (dependentname) {
+		dependent = GTK_WIDGET (gtk_builder_get_object (app->ui, dependentname));
+		g_object_set_data (G_OBJECT (w), "dependent", dependent);
+	}
+	return g_signal_connect (G_OBJECT (w), "toggled",
+				 G_CALLBACK (on_conn_port_change),
+				 (gpointer)app);
+}
 
 static void
 populate_prefs (MyApp *app)
 {
 	GtkWidget *w;
-	char *c;
+	char *widgetname;
 	int ctype;
 
 	ctype = gconf_client_get_int (app->client,
 				      CONFBASE"/connection_type", NULL);
-
-	set_dependent_widget (app, CONNECTION_BLUETOOTH,
-			ctype == CONNECTION_BLUETOOTH);
-	set_dependent_widget (app, CONNECTION_OTHER,
-			ctype == CONNECTION_OTHER);
-
-	w = GTK_WIDGET (gtk_builder_get_object (app->ui, "otherportentry"));
-	c  = gconf_client_get_string (app->client,
-				      CONFBASE"/other_serial", NULL);
-	if (c != NULL) {
-		gtk_entry_set_text (GTK_ENTRY (w), c);
-		g_free (c);
-	} else {
-		gtk_entry_set_text (GTK_ENTRY (w), "");
+	switch (ctype) {
+	case CONNECTION_BLUETOOTH:
+		widgetname = "btdevice";
+		break;
+	case CONNECTION_SERIAL1:
+		widgetname = "serialport1";
+		break;
+	case CONNECTION_SERIAL2:
+		widgetname = "serialport2";
+		break;
+	case CONNECTION_IRCOMM:
+		widgetname = "irdaport";
+		break;
+	case CONNECTION_OTHER:
+		/* fall through */
+	default:
+		widgetname = "otherport";
+		break;
 	}
-
-	S_ACTIVE("btdevice",  CONNECTION_BLUETOOTH);
-
-	S_ACTIVE("serialport1", CONNECTION_SERIAL1);
-	S_ACTIVE("serialport2", CONNECTION_SERIAL2);
-	S_ACTIVE("irdaport", CONNECTION_IRCOMM);
-	S_ACTIVE("otherport", CONNECTION_OTHER);
+	w = GTK_WIDGET (gtk_builder_get_object (app->ui, widgetname));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
 }
 
 static void
 apply_prefs (MyApp *app)
 {
-	GtkWidget *w;
-
-	w = GTK_WIDGET (gtk_builder_get_object (app->ui, "otherportentry"));
-	gconf_client_set_string (app->client,
-				 CONFBASE"/other_serial",
-				 gtk_entry_get_text (GTK_ENTRY (w)), NULL);
-
 	reconnect_phone (app);
 }
 
@@ -391,13 +401,11 @@ initialise_dequeuer (GConfClient *client, guint cnxn_id,
 void
 ui_init (MyApp *app)
 {
+	GtkWidget *btchooser, *btdevice;
 	GConfBridge *bridge;
-	GtkWidget *w;
 	GtkWidget *ep = e_phone_entry_new ();
 
 	app->ui = get_ui (app, NULL);
-	bridge = gconf_bridge_get ();
-
 	if (!app->ui)
 		g_error ("Couldn't load user interface.");
 
@@ -413,19 +421,27 @@ ui_init (MyApp *app)
 			  app);
 
 	/* Set Bluetooth options */
-	g_signal_connect (gtk_builder_get_object (app->ui, "btchooser"),
+	btchooser = GTK_WIDGET (gtk_builder_get_object (app->ui, "btchooser"));
+	btdevice = GTK_WIDGET (gtk_builder_get_object (app->ui, "btdevice"));
+	g_signal_connect (btchooser,
 			  "chooser-created",
 			  G_CALLBACK (chooser_created),
 			  NULL);
+	g_signal_connect (btchooser,
+			  "notify::is-available",
+			  G_CALLBACK (is_available_changed),
+			  btdevice);
 
 	/* connect signal handlers for radio buttons */
-	S_CONNECT("btdevice",  CONNECTION_BLUETOOTH);
-	S_CONNECT("serialport1", CONNECTION_SERIAL1);
-	S_CONNECT("serialport2", CONNECTION_SERIAL2);
-	S_CONNECT("irdaport", CONNECTION_IRCOMM);
-	S_CONNECT("otherport", CONNECTION_OTHER);
+	s_connect (app, "btdevice", "btchooser", CONNECTION_BLUETOOTH);
+	s_connect (app, "serialport1", NULL, CONNECTION_SERIAL1);
+	s_connect (app, "serialport2", NULL, CONNECTION_SERIAL2);
+	s_connect (app, "irdaport", NULL, CONNECTION_IRCOMM);
+	s_connect (app, "otherport", "otherportentry", CONNECTION_OTHER);
 
 	/* Connect a few toggle buttons */
+	bridge = gconf_bridge_get ();
+
 	gconf_bridge_bind_property (bridge,
 				    CONFBASE"/auto_retry",
 				    G_OBJECT (gtk_builder_get_object (app->ui, "auto_retry")),
@@ -443,10 +459,16 @@ ui_init (MyApp *app)
 				    G_OBJECT (gtk_builder_get_object (app->ui, "prefs_sound")),
 				    "active");
 
+	/* The other port address */
+	gconf_bridge_bind_property_delayed (bridge,
+				    CONFBASE"/other_serial",
+				    G_OBJECT (gtk_builder_get_object (app->ui, "otherportentry")),
+				    "text");
+
 	/* And the address chooser */
 	gconf_bridge_bind_property (bridge,
 				    CONFBASE"/bluetooth_addr",
-				    G_OBJECT (gtk_builder_get_object (app->ui, "btchooser")),
+				    G_OBJECT (btchooser),
 				    "device");
 
 	/* set up popup on message */
@@ -555,7 +577,7 @@ dequeue_message (MyApp *app)
 	g_list_free_1 (ptr);
 
 	set_icon_state (app);
-	
+
 	return TRUE;
 }
 
